tokyo
======

Tokyo Mortality data 
--------------------

* Tokyomortality.csv: Attribute data (n=262, k=9)
* Readme_tokyomortality.txt: Metadata
* tokyomet262.shp: Polygon shapefile (n=262)

For testing against GWR4 software
---------------------------------

* tokyo_BS_NN_listwise.csv: bisquare nearest neighbor kernel model output
* tokyo_BS_NN_summary.txt: bisquare nearest neighbor kernel model summary
* tokyo_BS_NN.ctl: bisquare nearest neighbor kernel control file

* tokyo_BS_NN_OFF_listwise.csv: bisquare nearest neighbor kernel model w/ offset output
* tokyo_BS_NN_OFF_summary.txt: bisquare nearest neighbor kernel model w/ offset summary
* tokyo_BS_NN_OFF.ctl: bisquare nearest neighbor kernel w/ offset control file

* tokyo_GS_NN_listwise.csv: Gaussian nearest neighbor kernel model output
* tokyo_GS_NN_summary.txt: Gaussian nearest neighbor kernel model summary
* tokyo_GS_NN.ctl: Gaussian nearest neighbor kernel control file

* tokyo_BS_F_listwise.csv: bisquare fixed kernel model output
* tokyo_BS_F_summary.txt: bisquare fixed kernel model summary
* tokyo_BS_F.ctl: bisquare fixed kernel control file

* tokyo_GS_F_listwise.csv: Gaussian fixed kernel model output
* tokyo_GS_F_summary.txt: Gaussian fixed kernel model summary
* tokyo_GS_F.ctl: Gaussian fixed kernel control file

Source: Nakaya T, Fotheringham A, Brunsdon C, Charlton M. Geographically weighted poisson regression for disease association mapping. Statistics in Medicine. 2005;24(17):2695–2717. https://doi.org/10.1002/sim.2129